/****************************************************************************/
/*  Copyright © 2012-2015 Mehdi Dogguy <mehdi@debian.org>                   */
/*                                                                          */
/*  This file is part of Dochelp.                                           */
/*                                                                          */
/*  Dochelp is free software: you can redistribute it and/or modify it      */
/*  under the terms of the GNU General Public License as published by the   */
/*  Free Software Foundation, either version 3 of the License, or (at your  */
/*  option) any later version.                                              */
/*                                                                          */
/*  Dochelp is distributed in the hope that it will be useful, but WITHOUT  */
/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or   */
/*  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License   */
/*  for more details.                                                       */
/*                                                                          */
/*  You should have received a copy of the GNU General Public License       */
/*  along with Dochelp.  If not, see <http://www.gnu.org/licenses/>.        */
/****************************************************************************/

div.document {
  margin: 1em;
  padding: 0.5em;
  background-color: #eee;
}

div.documents {
  margin-top: 0.3em;
  padding-left: 0.2em;
  background-color: #fff;
}

span.doc {
  font-size: 80%;
  margin-right: 0.5em;
}

div.abstract, div.authors, div.section {
  font-size: 80%;
}

div#count {
  font-size: 70%;
}

div#footer {
  border-top: 2px solid #d70751;
  padding: 0.5em;
}
